library(colortools)
library(plspm)

# Set working directory then read in data
setwd("/Users/emilywaddell/Desktop")
data <- read.csv("Plot_measured_data.csv", header = TRUE, na.strings = "NA")

# Measured variables included in PLSPM models ####
#Fragmentation
Site <- data$Site_code
Plot <- data$Site_plot_code
Edge.density <- scale(data$Edge.in.2km.buffer/data$Area.in.2km.buffer)
Age <- scale(log1p(data$Fragmentation.age))
Non.forest <- scale(data$Amount.of.non.forest.in.2km)
#Soil 
Avail.P <- (scale(log10(data$Soil.available.P)))
pH <- scale(log10(data$Soil.pH))
#Disturbance
Dips <- (scale(sqrt(data$Number.of.large.dipterocarps))*-1)
WD <- (scale(log10(data$Mean.wd.10cm))*-1)
#Propagule pressure
Outside.rich <- scale(data$Outside.exotic.richness)
Outside.abun <- scale(data$Outside.exotic.abundance)
#Total native community
Total.stems <- scale(data$Total.native.stems)
Total.richness <- scale(data$Total.native.richness)
Total.PD <- scale(data$Total.native.phylo.diversity)
#Adult tree native community
Adult.stems <- scale(data$Native.adult.tree.stems)
Adult.richness <- scale(data$Native.adult.tree.species.richness)
Adult.PD <- scale(data$Native.adult.tree.phylo.diversity)
#Tree sapling native community
Sapling.stems <- scale(data$Native.sapling.stems)
Sapling.richness <- scale(data$Native.sapling.species.richness)
Sapling.PD <- scale(data$Native.sapling.phylo.diversity)
#Tree seedling native community
Seedling.stems <- scale(data$Native.seedling.stems)
Seedling.richness <- scale(data$Native.seedling.species.richness)
Seedling.PD <- scale(data$Native.seedlings.phylo.diversity)
#Ground vegetation native community
Ground.veg.stems <- scale(data$Native.ground.veg.stems)
Ground.veg.richness <-  scale(data$Native.ground.veg.species.richness)
Ground.veg.PD <- scale(data$Native.ground.veg.phylo.diversity)
#Invasion
Exotic.abundance <- scale(log1p(data$Plot.exotic.abundance))
Exotic.richness <- scale(log1p(data$Plot.exotic.richness))

# PLSPM: Native -> Invasion ####
# Format and model assessment of Partial least squares path modelling follows 
# Sanchez G (2013) PLS Path Modeling with R. Trowchez Editions, Berkeley
# Total native community ####
data_pls <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                       pH, Avail.P, Total.richness, Total.PD, Outside.rich, 
                       #number of native stems added in full model but did not load high enough (>0.7) in 'Outer model:loadings' assessment 
                       Outside.abun, Exotic.abundance, Exotic.richness)   

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) #frag(4)
Soil = c(1, 1, 0, 0, 0, 0)
Natives = c(0, 0, 1, 0, 0, 0) #frag(1), dist(5)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 0, 1, 0) #natives(2), soil(3)

# path matrix created by row binding
pathway = rbind(Frag., Dist., Soil, Natives, Prop., Exotics)
# add column names (optional)
colnames(pathway) = rownames(pathway)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:15) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")

pls2 <- plspm(data_pls, pathway, blocks, modes = modes)
summary(pls2)
plot(pls2, arr.pos = 0.35)

#Two-sided P-values for standardised path coefficients estimated by 10,000 bootstrap estimations.
#Accommodating for site effects by taking bootstrap samples at the level of site
plsBSgp <- replicate(10000, {
  sampleGps <-  sample(unique(data_pls$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_pls$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_pls[rowId,]
  pls2 <- plspm(xBS, pathway, blocks, modes = modes)
  coeff <- pls2$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp <- t(plsBSgp)
plsBSgp <- plsBSgp[,colSums(plsBSgp) != 0]
apply(plsBSgp, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})

# Adult tree community ####
data_adults <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                          pH, Avail.P, Adult.richness, Adult.stems, Adult.PD, 
                          Outside.rich, Outside.abun, Exotic.abundance, Exotic.richness)   

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) #frag(4)
Soil = c(1, 1, 0, 0, 0, 0)
Natives = c(0, 1, 0, 0, 0, 0) #frag(1)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 0, 1, 0) #natives(2), soil(3)

# path matrix created by row binding
pathway_adults = rbind(Frag., Dist., Soil, Natives, Prop., Exotics)
# add column names (optional)
colnames(pathway) = rownames(pathway)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:12, 13:14, 15:16) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_adults = plspm(data_adults, pathway_adults, blocks, modes = modes)
summary(pls_adults)
# plotting results (inner model)
plot(pls_adults, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp_adult <- replicate(10000, {
  sampleGps <-  sample(unique(data_adults$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_adults$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_adults[rowId,]
  pls_adults <- plspm(xBS, pathway_adults, blocks, modes = modes)
  coeff <- pls_adults$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp_adult <- t(plsBSgp_adult)
plsBSgp_adult <- plsBSgp_adult[,colSums(plsBSgp_adult) != 0]
apply(plsBSgp_adult, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_adult, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})


# Tree sapling community ####
data_saps <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                        pH, Avail.P, Sapling.richness, Sapling.PD, Sapling.stems, 
                        Outside.rich, Outside.abun, Exotic.abundance, Exotic.richness)  

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) #frag(4)
Soil = c(1, 1, 0, 0, 0, 0)
Natives = c(0, 1, 0, 0, 0, 0) #soil(1), frag(5)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 0, 1, 0) #soil(2), natives(3)

# path matrix created by row binding
pathway_saps = rbind(Frag., Dist., Soil, Natives, Prop., Exotics)
# add column names (optional)
colnames(pathway_saps) = rownames(pathway_saps)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:12, 13:14, 15:16) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_saps = plspm(data_saps, pathway_saps, blocks, modes = modes)
summary(pls_saps)
# plotting results (inner model)
plot(pls_saps, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp_saps <- replicate(10000, {
  sampleGps <-  sample(unique(data_saps$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_saps$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_saps[rowId,]
  pls_saps <- plspm(xBS, pathway_saps, blocks, modes = modes)
  coeff <- pls_saps$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp_saps <- t(plsBSgp_saps)
plsBSgp_saps <- plsBSgp_saps[,colSums(plsBSgp_saps) != 0]
apply(plsBSgp_saps, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_saps, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})


# Tree seedling community ####
data_seeds <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                         pH, Avail.P, Seedling.stems, Seedling.PD, Seedling.richness, 
                         Outside.rich, Outside.abun, Exotic.abundance, Exotic.richness)    

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) #frag(4)
Soil = c(1, 1, 0, 0, 0, 0)
Natives = c(1, 0, 0, 0, 0, 0) #soil(2), dist(5)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 0, 1, 0) #natives(1), soil(3)

# path matrix created by row binding
pathway_seeds = rbind(Frag., Dist., Soil, Natives, Prop., Exotics)
# add column names (optional)
colnames(pathway_seeds) = rownames(pathway_seeds)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:12, 13:14, 15:16) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_seeds = plspm(data_seeds, pathway_seeds, blocks, modes = modes)
summary(pls_seeds)
# plotting results (inner model)
plot(pls_seeds, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp_seeds <- replicate(10000, {
  sampleGps <-  sample(unique(data_seeds$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_seeds$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_seeds[rowId,]
  pls_seeds <- plspm(xBS, pathway_seeds, blocks, modes = modes)
  coeff <- pls_seeds$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp_seeds <- t(plsBSgp_seeds)
plsBSgp_seeds <- plsBSgp_seeds[,colSums(plsBSgp_seeds) != 0]
apply(plsBSgp_seeds, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_seeds, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})


# Ground vegetation community ####
data_under <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                         pH, Avail.P, Ground.veg.PDD, Ground.veg.richness, 
                         #number of native stems added in full model but did not load high enough (>0.7) in 'Outer model:loadings' assessment 
                         Outside.rich, Outside.abun, Exotic.abundance, Exotic.richness)   
# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) #frag(5)
Soil = c(1, 1, 0, 0, 0, 0)
Natives = c(0, 0, 1, 0, 0, 0) #frag(2), dist(4)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 0, 1, 0) #native(1), soil(3)

# path matrix created by row binding
pathway_under = rbind(Frag., Dist., Soil, Natives, Prop., Exotics)
# add column names (optional)
colnames(pathway_under) = rownames(pathway_under)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:15) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_under = plspm(data_under, pathway_under, blocks, modes = modes)
summary(pls_under)
# plotting results (inner model)
plot(pls_under, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE 
plsBSgp_under <- replicate(10000, {
  sampleGps <-  sample(unique(data_under$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_under$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_under[rowId,]
  pls_under <- plspm(xBS, pathway_under, blocks, modes = modes)
  coeff <- pls_under$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})



plsBSgp_under <- t(plsBSgp_under)
plsBSgp_under <- plsBSgp_under[,colSums(plsBSgp_under) != 0]
apply(plsBSgp_under, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_under, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})





# PLSM: Invasion -> Native ####
# Total native community ####
data_pls <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                       pH, Avail.P, Outside.rich, Outside.abun, Exotic.abundance, 
                       Exotic.richness, Total.richness, Total.PD)   
#number of native stems added in full model but did not load high enough (>0.7) in 'Outer model:loadings' assessment 


# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) 
Soil = c(1, 1, 0, 0, 0, 0)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 1, 0, 0) 
Natives = c(0, 0, 1, 0, 0, 0)

# path matrix created by row binding
pathway = rbind(Frag., Dist., Soil, Prop., Exotics, Natives)
# add column names (optional)
colnames(pathway) = rownames(pathway)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:15) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")

pls2 <- plspm(data_pls, pathway, blocks, modes = modes)
summary(pls2)
plot(pls2, arr.pos = 0.35)


#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp <- replicate(10000, {
  sampleGps <-  sample(unique(data_pls$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_pls$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_pls[rowId,]
  pls2 <- plspm(xBS, pathway, blocks, modes = modes)
  coeff <- pls2$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp <- t(plsBSgp)
plsBSgp <- plsBSgp[,colSums(plsBSgp) != 0]
apply(plsBSgp, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})

# Adult tree community ####
data_adults <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                          pH, Avail.P, Outside.rich, Outside.abun, Exotic.abundance, 
                          Exotic.richness, Adult.richness, Adult.stems, Adult.PD)   

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) 
Soil = c(1, 1, 0, 0, 0, 0)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 1, 0, 0) 
Natives = c(0, 1, 0, 0, 0, 0)

# path matrix created by row binding
pathway_adults = rbind(Frag., Dist., Soil, Prop., Exotics, Natives)
# add column names (optional)
colnames(pathway) = rownames(pathway)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:16)
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_adults = plspm(data_adults, pathway_adults, blocks, modes = modes)
summary(pls_adults)
# plotting results (inner model)
plot(pls_adults, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp_adult <- replicate(10000, {
  sampleGps <-  sample(unique(data_adults$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_adults$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_adults[rowId,]
  pls_adults <- plspm(xBS, pathway_adults, blocks, modes = modes)
  coeff <- pls_adults$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp_adult <- t(plsBSgp_adult)
plsBSgp_adult <- plsBSgp_adult[,colSums(plsBSgp_adult) != 0]
apply(plsBSgp_adult, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_adult, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})


# Tree sapling community ####
data_saps <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                        pH, Avail.P, Outside.rich, Outside.abun, Exotic.abundance, 
                        Exotic.richness, Sapling.richness, Sapling.PD, Sapling.stems)  

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) 
Soil = c(1, 1, 0, 0, 0, 0)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 1, 0, 0) 
Natives = c(0, 1, 0, 0, 1, 0)

# path matrix created by row binding
pathway_saps = rbind(Frag., Dist., Soil, Prop., Exotics, Natives)
# add column names (optional)
colnames(pathway_saps) = rownames(pathway_saps)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:16) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_saps = plspm(data_saps, pathway_saps, blocks, modes = modes)
summary(pls_saps)
# plotting results (inner model)
plot(pls_saps, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp_saps <- replicate(10000, {
  sampleGps <-  sample(unique(data_saps$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_saps$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_saps[rowId,]
  pls_saps <- plspm(xBS, pathway_saps, blocks, modes = modes)
  coeff <- pls_saps$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp_saps <- t(plsBSgp_saps)
plsBSgp_saps <- plsBSgp_saps[,colSums(plsBSgp_saps) != 0]
apply(plsBSgp_saps, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_saps, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})


# Tree seedling community ####
data_seeds <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                         pH, Avail.P, Outside.rich, Outside.abun, Exotic.abundance, 
                         Exotic.richness, Seedling.stems, Seedling.PD, Seedling.richness)    

# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) 
Soil = c(1, 1, 0, 0, 0, 0)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 1, 0, 0) 
Natives = c(1, 0, 0, 0, 1, 0)

# path matrix created by row binding
pathway_seeds = rbind(Frag., Dist., Soil, Prop., Exotics, Natives)
# add column names (optional)
colnames(pathway_seeds) = rownames(pathway_seeds)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:16) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_seeds = plspm(data_seeds, pathway_seeds, blocks, modes = modes)
summary(pls_seeds)
# plotting results (inner model)
plot(pls_seeds, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE
plsBSgp_seeds <- replicate(10000, {
  sampleGps <-  sample(unique(data_seeds$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_seeds$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_seeds[rowId,]
  pls_seeds <- plspm(xBS, pathway_seeds, blocks, modes = modes)
  coeff <- pls_seeds$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})

plsBSgp_seeds <- t(plsBSgp_seeds)
plsBSgp_seeds <- plsBSgp_seeds[,colSums(plsBSgp_seeds) != 0]
apply(plsBSgp_seeds, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_seeds, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})


# Ground vegetation ####
data_under <- data.frame(Site, Plot, Non.forest, Edge.density, Age, Dips, WD,
                         pH, Avail.P,  Outside.rich, Outside.abun, Exotic.abundance, 
                         Exotic.richness, Ground.veg.PDD, Ground.veg.richness) 
#number of native stems added in full model but did not load high enough (>0.7) in 'Outer model:loadings' assessment 


# rows of the inner model matrix
## stepwise removal of non-sign. regressions - order of removal in brackets
Frag. = c(0, 0, 0, 0, 0, 0)
Dist. = c(0, 0, 0, 0, 0, 0) 
Soil = c(1, 1, 0, 0, 0, 0)
Prop. = c(1, 0, 0, 0, 0, 0)
Exotics = c(0, 1, 0, 1, 0, 0) 
Natives = c(0, 0, 1, 0, 0, 0)

# path matrix created by row binding
pathway_under = rbind(Frag., Dist., Soil, Prop., Exotics, Natives)
# add column names (optional)
colnames(pathway_under) = rownames(pathway_under)
# define list of indicators: what variables are associated with
# what latent variables
blocks = list(3:5, 6:7, 8:9, 10:11, 12:13, 14:15) 
# all latent variables are measured in a reflective way
modes = c("A", "A", "A", "A", "A", "A")                    

# run plspm analysis
pls_under = plspm(data_under, pathway_under, blocks, modes = modes)
summary(pls_under)
# plotting results (inner model)
plot(pls_under, box.size = 0.1)

#BOOTSTRAPPING ACCOUNTING FOR SITE 
plsBSgp_under <- replicate(10000, {
  sampleGps <-  sample(unique(data_under$Site), replace = TRUE)
  rowId <- lapply(sampleGps, function(i){
    which(data_under$Site == i)
  })
  rowId <- unlist(rowId)
  xBS <- data_under[rowId,]
  pls_under <- plspm(xBS, pathway_under, blocks, modes = modes)
  
  coeff <- pls_under$path_coefs 
  vcoeff <- as.vector(coeff)
  names(vcoeff) <- paste(rep(colnames(coeff), each=nrow(coeff)), rownames(coeff))
  return(vcoeff)
})



plsBSgp_under <- t(plsBSgp_under)
plsBSgp_under <- plsBSgp_under[,colSums(plsBSgp_under) != 0]
apply(plsBSgp_under, MARGIN=2, FUN=quantile, c(0.025, 0.975))

apply(plsBSgp_under, MARGIN=2, FUN=function(x){
  if(mean(x) > 0) p <- 2*mean(x < 0)
  if(mean(x) < 0) p <- 2*mean(x > 0)
  return(p)
})





